@@ -13,7 +13,7 @@ from fief_client.client import (
     FiefUserInfo,
 )
 
-__version__ = "0.14.2"
+__version__ = "0.14.3"
 
 __all__ = [
     "Fief",
@@ -27,4 +27,7 @@ __all__ = [
     "FiefAccessTokenMissingScope",
     "FiefAccessTokenInvalid",
     "FiefIdTokenInvalid",
+    "crypto",
+    "pkce",
+    "integrations",
 ]
